@@ -40,13 +40,14 @@ Example usage::
         writer(out, schema, records)
 '''
 
-__version_info__ = (0, 19, 3)
+__version_info__ = (0, 19, 4)
 __version__ = '%s.%s.%s' % __version_info__
 
 
 import fastavro.read
 import fastavro.write
 import fastavro.schema
+import fastavro.validation
 
 
 def _acquaint_schema(schema):
@@ -70,6 +71,7 @@ dump = fastavro.write.dump
 acquaint_schema = _acquaint_schema
 fastavro.schema.acquaint_schema = _acquaint_schema
 is_avro = fastavro.read.is_avro
+validate = fastavro.validation.validate
 
 __all__ = [
     n for n in locals().keys() if not n.startswith('_')
